PRO ace_column

; user input settings
; -------------------
 profile_file =  'profiles.ace'

fileOutUv = 'midlat.ace'

nheaderlines = 3
nlayers      = 121
nGases       = 14

defGases = ['o3','no2','so2','clo','bro','no3','hcho','oclo','h2o','co2','n2o','co','ch4','o2' ]

defSciaUV  = ['o3','no2','so2','clo','bro','no3','hcho','oclo' ] 
defSciaNIR = ['h2o','co2','n2o','co','ch4','o2' ]


; plots only one trace gas profile (select !)
; -------------------------------------------
tg             = fltarr(nGases)
k_arr          = intarr(nlayers)
altitude       = fltarr(nlayers)
p_arr          = fltarr(nlayers)
t_arr          = fltarr(nlayers)
tg_arr         = fltarr(nlayers)
air_density    = fltarr(nlayers)
tg_vmr         = fltarr(nGases,nlayers)
tg_density     = fltarr(nGases,nlayers)


; open file and read header lines
; -------------------------------
openr, 1, profile_file
print, ' *** reading: ', profile_file
dum = string(60)
for i = 1, nheaderlines do begin
    readf, 1, dum
    print, dum
endfor 

; read Z, P, T, and tracegas (tg) VMR
; -----------------------------------
for i = 0, nlayers-1 do begin
    readf, 1, k,z,p,t,tg

    idx              = nlayers-i-1   
    altitude(idx)    = z
    k_arr(idx)       = k
    p_arr(idx)       = p
    t_arr(idx)       = t

;   [air_density]    = molecules/cm3
    air_density(idx) = p * 100.0 / (1.38066e-23*t) * 1e-6 
;   [tg_vmr]         = ppm
    tg_vmr(*,idx)    = tg
;   [tg_density]     = molecules/cm3
    tg_density(*,idx)= air_density(idx)*tg_vmr(*,idx)*1e-6
endfor

; determine vertical column
; -------------------------
col = fltarr(nGases)
for i = 0, nlayers-2 do begin
    col = col + ( tg_density(*,i)+tg_density(*,i+1) ) * 0.5* $
                ( altitude(i+1)-altitude(i) ) * 1.0e5
endfor


; write file into SCIATRAN format
openw, 2, fileOutUv
printf, 2, ';', defSciaUV
for I = 0, nlayers-1 do begin
   idx = nlayers-i-1
   printf, 2, format='(1x,I3,3x,F5.1,2x,e9.3,2x,f5.1,8(1x,e10.3))', idx+1, altitude(idx), $
     p_arr(idx), t_arr(idx), tg_vmr(0:7,idx)
endfor
close, 2 

for K = 0, 5 do begin 
    openw,3, 'ace_'+defSciaNIR(K)+'.dat'
    printf,3,'; No  z[km]   p[mb]    t[K]    VMR[ppm]', defSciaNIR(K)

    for I = 0, nlayers-1 do begin
        idx = nlayers-i-1
        printf, 3, format='(1x,I3,3x,F5.1,2x,e9.3,2x,f5.1,1x,e10.3)', idx+1, altitude(idx), $
          p_arr(idx), t_arr(idx), tg_vmr(8+K,idx)
    endfor
    close, 3
endfor




doPrint = 'N'
if (doPrint eq 'Y') then begin
; print results
; -------------
print
print, '   layer            z     air_dens       tg_vmr   tg_density'
print, '                 [km]       [cm-3]        [ppm]       [cm-3]'
print, ' -----------------------------------------------------------'
for i = 0, nlayers-1 do begin
    idx = nlayers-i-1
    print, idx+1, altitude(idx), air_density(idx), tg_vmr(0,idx), tg_density(0,idx)
endfor
print, ' -----------------------------------------------------------'
print, ' *** vertical column [molec./cm2]: ', col(0)

; convert to g/m^2:
conv=18.0/6.022e23
print, ' *** in [g/cm^2]:                   ', col(0)*conv
endif


doPlot='N'
; plot results
; ------------
if (doPlot eq 'Y') then begin
    !p.font=-5
    !p.charsize=1.2
    !p.title='ACE O3 profile ('+profile_file+')'
    !x.title='Density [molecules/cm3]'
    !y.title='Altitude [km]'
    !y.range=[0,120]

    plot, tg_density(0,*), altitude(*)
endif


end
  



